﻿'___________________________________________________________

'                     P H I D G E T   C O N T R O L   B O A R D
'                                             Demo 1
'                                Windows Desktop Version
'                                         Ron Kessler
'                                    Created 10/23/09
'___________________________________________________________

'Updated 1/7/2010

'Getting set up:

'1. In order to run this app, you must install the Phidget framework. Go to Phidgets.com | Drivers.
'    Run the Windows 32 or 64 bit installer. Now you can build your app.

'2. In solution explorer, add a new reference to the phidget library. Rt. click on references and choose
'    browse. Go to c:\program files\phidgets\phidgets21.net.dll and select it.

'3. If you move/delete this reference or move this dll your program will not work. I usually create
'    a copy of this dll and add it to my app like I did for you in this project. It just makes sure
'    everything works all the time!

'4. When you add your check boxes, use the tag property to identify each one. My first relay is #0, the next is #1, etc.
'    We will use this tag property to tell which one they clicked.

'This app is made for the Phidget 0/0/4 board. It has 4 relays that you can control from this app.


Option Explicit On


Public Class Form1
    '---now create a new reference to the phidget dll. Be sure to include "WithEvents" in
    '   your Dim statement because the phidget library has built-in event handlers
    Dim WithEvents phidgetIFK As Phidgets.InterfaceKit

    '---this is the message for the caption used in all message boxes
    Const MSGTITLE As String = "Phidgets Demo 1 for Windows"


#Region "Load"
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Try
            phidgetIFK = New Phidgets.InterfaceKit  'create our phidget object now and open it
            phidgetIFK.open()

            'Defaults for text fields
            lblStatus.Text = "Not Connected"
        Catch ex As Exception
            DisplayErrorMsg("Unable to open the controller board.")
            Me.Close()

        End Try

    End Sub
#End Region



#Region "Manage Phidget"

    Private Sub phidgetIFK_Attach(ByVal sender As Object, ByVal e As Phidgets.Events.AttachEventArgs) Handles phidgetIFK.Attach
        '---this event is called from the Phidgets.dll when the board can speak to the computer

        Try
            'When the Phidget Intefacekit attaches update the form text boxes
            lblStatus.Text = "Connected"
            ResetRelays()


        Catch ex As Exception
            DisplayErrorMsg("Unable to attach to the controller board.")
        End Try


    End Sub

    Private Sub whichCircuit_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) _
        Handles Circuit1.CheckedChanged, Circuit2.CheckedChanged, Circuit3.CheckedChanged, Circuit4.CheckedChanged

        Try
            phidgetIFK.outputs(CType(sender, CheckBox).Tag) = CType(sender, CheckBox).CheckState
        Catch ex As Exception
            DisplayErrorMsg("Unable to set that circuit.")
        End Try


    End Sub

#End Region

#Region "Subroutines"
    Private Sub ResetRelays()
        '---initialize all relays to off N/O = Open
        For x As Integer = 0 To 3
            phidgetIFK.outputs(x) = 0            'the outputs collection keeps track of all the relays
        Next

    End Sub

    Private Sub DisplayErrorMsg(ByVal msg As String)

        MessageBox.Show(msg, MSGTITLE, MessageBoxButtons.OK, MessageBoxIcon.Information)

    End Sub

    Private Sub btnReset_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnReset.Click

        '---uncheck all checkbox controls by cycling through the forms collection
        For Each myControl As Control In Me.Controls
            If TypeOf myControl Is CheckBox Then
                Dim thisControl As CheckBox = DirectCast(myControl, CheckBox)
                thisControl.Checked = False
            End If
        Next
        ResetRelays()
    End Sub
#End Region

#Region "Clean up"
    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        '---it is always a good idea to disconnect the device when the program ends
        If phidgetIFK.Attached = True Then
            phidgetIFK.close()
        End If
    End Sub

    Private Sub btnEnd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEnd.Click
        Me.Close()

    End Sub
#End Region


End Class
